# Mapology

Simple python filters generating leaflet driven apps.

[License: MIT](https://git.sr.ht/~sthagen/mapology/tree/default/item/LICENSE)

[![version](https://img.shields.io/pypi/v/mapology.svg?style=flat)](https://pypi.python.org/pypi/mapology/)
[![downloads](https://pepy.tech/badge/mapology/month)](https://pepy.tech/project/mapology)
[![wheel](https://img.shields.io/pypi/wheel/mapology.svg?style=flat)](https://pypi.python.org/pypi/mapology/)
[![supported-versions](https://img.shields.io/pypi/pyversions/mapology.svg?style=flat)](https://pypi.python.org/pypi/mapology/)
[![supported-implementations](https://img.shields.io/pypi/implementation/mapology.svg?style=flat)](https://pypi.python.org/pypi/mapology/)

## Bug Tracker

Feature requests and bug reports are bested entered in the [todos of mapology](https://todo.sr.ht/~sthagen/mapology).

## Primary Source repository

The primary source repository of [mapology is at sourcehut](https://git.sr.ht/~sthagen/mapology)
a collection of tools useful for software development.
